summaryrefslogtreecommitdiffstats
path: root/nest/iface.h
diff options
context:
space:
mode:
Diffstat (limited to 'nest/iface.h')
-rw-r--r--nest/iface.h9
1 files changed, 3 insertions, 6 deletions
diff --git a/nest/iface.h b/nest/iface.h
index 1d26e7b..9f3a239 100644
--- a/nest/iface.h
+++ b/nest/iface.h
@@ -122,13 +122,10 @@ void neigh_prune(void);
struct iface_patt {
node n;
byte *pattern; /* Interface name pattern */
+ ip_addr prefix; /* Interface prefix */
+ int pxlen;
- /* Protocol-specific data follow, but keep them like this:
- struct rip_iface_patt {
- struct iface_patt i;
- whatever you (need);
- }
- */
+ /* Protocol-specific data follow after this structure */
};
struct iface_patt *iface_patt_match(list *, struct iface *);